Skip to contents

Returns availability and connection state for both backends, the active backend (if sb_connect() has been called), and the current schema.

Usage

sb_status()

Value

A list with dbi, api, backend, and schema entries