Returns availability and connection state for both backends, the active
backend (if sb_connect() has been called), and the current schema.
Returns availability and connection state for both backends, the active
backend (if sb_connect() has been called), and the current schema.